@@ -1244,6 +1244,7 @@ def compute_transmission_binned_mcmc(config_in, lines_label, reference='planetRF
             if key[-8:]=='contrast':
                 key_name = key[:-8] + 'Rh'
                 sample_size = len(results_dict['flat_chain'][:,val])
+                print(sample_size)
                 planet_ratio_sample = np.random.normal(planet_dict['radius_ratio'][0],planet_dict['radius_ratio'][1],size=sample_size)
                 results_dict['derived'][key_name] = {}
                 results_dict['derived'][key_name]['flat_chain'] = np.sqrt(results_dict['flat_chain'][:,val]/planet_ratio_sample**2 + 1.)
@@ -1343,22 +1344,23 @@ def plot_transmission_binned_mcmc(config_in, lines_label, night_input='', refere
 
     os.system('mkdir -p plots')
 
-    for night in night_list:
 
-
-        preparation_input = load_from_cpickle(
-            'transmission_preparation', config_in['output'], night)
+    # Workaround to check if the transmission spectrum has been obtained through PCA iterations
+    for night in night_dict:
+        preparation_input = load_from_cpickle('transmission_preparation', config_in['output'], night)
 
         if preparation_input.get('pca_output', False):
             if pca_iteration >= 0:
                 it_string = str(pca_iteration).zfill(2)
             else:
-                it_string = str(preparation_input.get('ref_iteration', 0)).zfill(2)
+                it_string = str(preparation_input.get('ref_iteration')).zfill(2)
         else:
             it_string = ''
-        preparation_input=None
+        preparation_input = None
+        break
 
 
+    for night in night_list:
 
         results_dict = load_from_cpickle(subroutine_name+'_'+sampler_name+'_results', config_in['output'], night, lines_label, it_string)
         print("   Transmission MCMC analysis for lines {0:s}, night: {1:s}  already performed".format(
@@ -1394,7 +1396,7 @@ def plot_transmission_binned_mcmc(config_in, lines_label, night_input='', refere
             results_dict['derived'] = {}
 
         # TODO improve output
-        print('   *** sampler output ')
+        print('   *** sampler output (plotting the chains)')
 
         sample_size = np.size(flat_chain, axis=0)
         dimen_size = np.size(flat_chain, axis=1)
@@ -1406,6 +1408,8 @@ def plot_transmission_binned_mcmc(config_in, lines_label, night_input='', refere
         }
 
         i_corner = 0
+
+
         for key, val in pams_dict.items():
             print('{0:24s}  {1:4d}  {2:12f}   {3:12f}  {4:12f} (15-84 p) ([{5:9f}, {6:9f}]) (start: {7:9f})'.format(key, val,
                                                                                                     chain_med[val,0],
@@ -1430,8 +1434,6 @@ def plot_transmission_binned_mcmc(config_in, lines_label, night_input='', refere
             i_corner += 1
 
 
-            print(' Plotting the chains... ')
-
             file_name = chains_dir + repr(val) + '.png'
             fig = plt.figure(figsize=(12, 12))
             plt.title(key)
@@ -1464,15 +1466,24 @@ def plot_transmission_binned_mcmc(config_in, lines_label, night_input='', refere
         output_file = get_filename(filename_rad, config_in['output'], night=night, lines=lines_label, it_string=it_string, extension='.pdf')
         print('   *** filename: ', output_file)
 
-        GTC = pygtc.plotGTC(chains=corner_plot['samples'],
-                            paramNames=corner_plot['labels'],
-                            truths=[corner_plot['truths'],corner_plot['start']],
-                            GaussianConfLevels=True,
-                            nConfidenceLevels=3,
-                            figureSize=12,
-                            labelRotation= (True,True),
-                            plotName='plots/'+output_file)
-
+        try:
+            GTC = pygtc.plotGTC(chains=corner_plot['samples'],
+                                paramNames=corner_plot['labels'],
+                                truths=[corner_plot['truths'],corner_plot['start']],
+                                GaussianConfLevels=True,
+                                nConfidenceLevels=3,
+                                figureSize=12,
+                                labelRotation= (True,True),
+                                plotName='plots/'+output_file)
+        except:
+            GTC = pygtc.plotGTC(chains=corner_plot['samples'],
+                                paramNames=corner_plot['labels'],
+                                truths=[corner_plot['truths'],corner_plot['start']],
+                                GaussianConfLevels=True,
+                                nConfidenceLevels=2,
+                                figureSize=12,
+                                labelRotation= (True,True),
+                                plotName='plots/'+output_file)
 
 
         GTC = None
